@@ -5,3 +5,5 @@ class LLMProvider(StrEnum):
     OPENAI = "OPENAI"
     GEMINI = "GEMINI"
     CLAUDE = "CLAUDE"
+    OLLAMA = "OLLAMA"
+    OPENROUTER = "OPENROUTER"
