@@ -2,5 +2,7 @@ from enum import StrEnum
 
 
 class VCSProvider(StrEnum):
+    GITEA = "GITEA"
     GITHUB = "GITHUB"
     GITLAB = "GITLAB"
+    BITBUCKET = "BITBUCKET"
