@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timezone
 
 from pydantic import BaseModel, Field
 
@@ -7,5 +7,5 @@ class LLMArtifactSchema(BaseModel):
     id: str
     prompt: str
     response: str | None = None
-    timestamp: str = Field(default_factory=datetime.utcnow().isoformat)
+    timestamp: str = Field(default_factory=lambda: datetime.now(timezone.utc).isoformat())
     prompt_system: str
